@@ -21,18 +21,17 @@ build_time_vars = {'ABIFLAGS': '',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe -Wall '
            '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -fstack-clash-protection -Wformat '
-           '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 '
-           '-g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-           '-fstack-protector-strong --param=ssp-buffer-size=4 '
-           '-fstack-clash-protection -Wformat -Wformat-security '
+           '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
            '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
            '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
            '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
-           '--param=ssp-buffer-size=4 -fstack-clash-protection -Wformat '
-           '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
-           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
+           '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
+           '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
+           '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
+           '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
+           '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
+           '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
+           '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CFLAGS_NODIST': '',
@@ -40,9 +39,9 @@ build_time_vars = {'ABIFLAGS': '',
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
                      '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                     '-fstack-clash-protection -Wformat -Wformat-security '
-                     '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-                     '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
+                     '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                     '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
+                     '-mfpu=neon -mthumb -Wno-psabi',
  'CONFIGURE_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
@@ -55,10 +54,10 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-shared' '--with-ensurepip=no' "
                 "'--with-dbmliborder=bdb' '--with-system-ffi=yes' 'CFLAGS=-O2 "
                 '-g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-                '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                '-fstack-clash-protection -Wformat -Wformat-security '
-                '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-                "-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi' "
+                '-fstack-protector-strong --param=ssp-buffer-size=4 -Wformat '
+                '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+                '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb '
+                "-Wno-psabi' "
                 "'PKG_CONFIG_PATH=:/usr/lib/pkgconfig:/usr/share/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.8',
@@ -612,10 +611,9 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
  'OPT': '-DNDEBUG -O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-        '-fstack-protector-strong --param=ssp-buffer-size=4 '
-        '-fstack-clash-protection -Wformat -Wformat-security '
-        '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
+        '-fstack-protector-strong --param=ssp-buffer-size=4 -Wformat '
+        '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+        '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -648,22 +646,19 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 '
                              '-g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fexceptions -fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 '
-                             '-fstack-clash-protection -Wformat '
+                             '--param=ssp-buffer-size=4 -Wformat '
                              '-Wformat-security -Wl,-z,relro,-z,now '
                              '-fmessage-length=0 -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
                              '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fexceptions -fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 '
-                             '-fstack-clash-protection -Wformat '
+                             '--param=ssp-buffer-size=4 -Wformat '
                              '-Wformat-security -Wl,-z,relro,-z,now '
                              '-fmessage-length=0 -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
                              '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 '
                              '-fexceptions -fstack-protector-strong '
-                             '--param=ssp-buffer-size=4 '
-                             '-fstack-clash-protection -Wformat '
+                             '--param=ssp-buffer-size=4 -Wformat '
                              '-Wformat-security -Wl,-z,relro,-z,now '
                              '-fmessage-length=0 -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
@@ -675,19 +670,17 @@ build_time_vars = {'ABIFLAGS': '',
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe -Wall '
               '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions -fstack-protector-strong '
-              '--param=ssp-buffer-size=4 -fstack-clash-protection -Wformat '
-              '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
-              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
-              '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-              '-fstack-protector-strong --param=ssp-buffer-size=4 '
-              '-fstack-clash-protection -Wformat -Wformat-security '
+              '--param=ssp-buffer-size=4 -Wformat -Wformat-security '
               '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
               '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe '
               '-Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
-              '-fstack-protector-strong --param=ssp-buffer-size=4 '
-              '-fstack-clash-protection -Wformat -Wformat-security '
-              '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-              '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
+              '-fstack-protector-strong --param=ssp-buffer-size=4 -Wformat '
+              '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
+              '-O2 -g -pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
+              '-fstack-protector-strong --param=ssp-buffer-size=4 -Wformat '
+              '-Wformat-security -Wl,-z,relro,-z,now -fmessage-length=0 '
+              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi',
  'PY_CFLAGS_NODIST': '-std=c99 -Wextra -Wno-unused-result '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration  '
@@ -696,20 +689,20 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g -pipe '
                    '-Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
                    '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-fstack-clash-protection -Wformat -Wformat-security '
-                   '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g '
-                   '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
+                   '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                   '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
+                   '-mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
                    '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-fstack-clash-protection -Wformat -Wformat-security '
-                   '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g '
-                   '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
+                   '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                   '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
+                   '-mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
+                   '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
                    '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                   '-fstack-clash-protection -Wformat -Wformat-security '
-                   '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -std=c99 '
-                   '-Wextra -Wno-unused-result -Wno-unused-parameter '
+                   '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                   '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
+                   '-mfpu=neon -mthumb -Wno-psabi -std=c99 -Wextra '
+                   '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration  '
                    '-I./Include/internal -I. -I./Include -fPIC -DPy_BUILD_CORE',
@@ -723,21 +716,21 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare -DNDEBUG -O2 -g '
                         '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-fstack-clash-protection -Wformat -Wformat-security '
-                        '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g '
-                        '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
+                        '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                        '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
+                        '-mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
+                        '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-fstack-clash-protection -Wformat -Wformat-security '
-                        '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi -O2 -g '
-                        '-pipe -Wall -Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
+                        '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                        '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
+                        '-mfpu=neon -mthumb -Wno-psabi -O2 -g -pipe -Wall '
+                        '-Wp,-D_FORTIFY_SOURCE=2 -fexceptions '
                         '-fstack-protector-strong --param=ssp-buffer-size=4 '
-                        '-fstack-clash-protection -Wformat -Wformat-security '
-                        '-Wl,-z,relro,-z,now -fmessage-length=0 -march=armv7-a '
-                        '-mfloat-abi=hard -mfpu=neon -mthumb -Wno-psabi '
-                        '-std=c99 -Wextra -Wno-unused-result '
-                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wformat -Wformat-security -Wl,-z,relro,-z,now '
+                        '-fmessage-length=0 -march=armv7-a -mfloat-abi=hard '
+                        '-mfpu=neon -mthumb -Wno-psabi -std=c99 -Wextra '
+                        '-Wno-unused-result -Wno-unused-parameter '
+                        '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration  '
                         '-I./Include/internal -I. -I./Include -fPIC',
  'Py_DEBUG': 0,
